# kanga

MCMC diagnostics in Python.

kanga can be installed using pip or anaconda.

To install kanga using pip, run
```
pip install kanga
```

To install kanga using anaconda, firstly add the conda-forge channel by running
```
conda config --add channels conda-forge
```
and subsequently run
```
conda install -c papamarkou kanga
```
To install kanga using anaconda without adding the conda-forge channel, run
```
conda install -c papamarkou -c conda-forge kanga
```
